@@ -265,6 +265,26 @@ unsigned int Fl_lighter(unsigned int c);
 
 unsigned int Fl_darker(unsigned int c);
 
+void Fl_set_box_type_cb(int, void (*cb)(int, int, int, int, unsigned int), int, int, int, int);
+
+int Fl_draw_box_active(void);
+
+unsigned int Fl_gray_ramp(int i);
+
+unsigned int Fl_color_average(unsigned int, unsigned int, float f);
+
+unsigned int Fl_contrast(unsigned int c1, unsigned int c2);
+
+unsigned int Fl_rgb_color(unsigned char r, unsigned char g, unsigned char b);
+
+unsigned int Fl_rgb_color2(unsigned char g);
+
+unsigned int Fl_cmap(unsigned int c);
+
+unsigned int Fl_box_color(unsigned int c);
+
+void Fl_set_box_color(unsigned int c);
+
 #ifdef __cplusplus
 }
 #endif
