@@ -580,3 +580,45 @@ unsigned int Fl_lighter(unsigned int c) {
 unsigned int Fl_darker(unsigned int c) {
     return fl_darker(c);
 }
+
+void Fl_set_box_type_cb(int box, void (*cb)(int, int, int, int, unsigned int), int x, int y, int w, int h) {
+    Fl::set_boxtype((Fl_Boxtype)box, cb, x, y, w, h);
+}
+
+int Fl_draw_box_active(void) {
+    return Fl::draw_box_active();
+}
+
+unsigned int Fl_gray_ramp(int i) {
+    return fl_gray_ramp(i);
+}
+
+unsigned int Fl_color_average(unsigned int c1, unsigned int c2, float weight) {
+    return fl_color_average(c1, c2, weight);
+}
+
+unsigned int Fl_contrast(unsigned int c1, unsigned int c2) {
+    return fl_contrast(c1, c2);
+}
+
+unsigned int Fl_rgb_color(unsigned char r, unsigned char g, unsigned char b) {
+    return fl_rgb_color(r, g, b);
+}
+
+unsigned int Fl_rgb_color2(unsigned char g) {
+    return fl_rgb_color(g);
+}
+
+extern unsigned fl_cmap[256];
+
+unsigned int Fl_cmap(unsigned int c) {
+    return fl_cmap[c];
+}
+
+unsigned int Fl_box_color(unsigned int c) {
+    return (Fl_Color)Fl::box_color((Fl_Color)c);
+}
+
+void Fl_set_box_color(unsigned int c) {
+    Fl::set_box_color((Fl_Color)c);
+}
